@@ -11,7 +11,10 @@ Run all test cases.
 """
 
 import sys, os
-import unittest
+if sys.version < "2.7":
+    import unittest2 as unittest
+else:
+    import unittest
 
 import numpy
 import blz
@@ -41,8 +44,6 @@ def print_versions():
     else:
         print("Numexpr version:   not available "
               "(version >= %s not detected)" %  blz.min_numexpr_version)
-    from Cython.Compiler.Main import Version as Cython_Version
-    print("Cython version:    %s" % Cython_Version.version)
     print("Python version:    %s" % sys.version)
     if os.name == "posix":
         (sysname, nodename, release, version, machine) = os.uname()
